@@ -1,7 +1,8 @@
 package Parallel::ForkManager::Segmented::Base;
-$Parallel::ForkManager::Segmented::Base::VERSION = '0.2.1';
+$Parallel::ForkManager::Segmented::Base::VERSION = '0.4.0';
 use strict;
 use warnings;
+use autodie;
 use 5.014;
 
 sub new
@@ -76,6 +77,21 @@ sub process_args
     };
 }
 
+sub serial_run
+{
+    my ( $self, $processed ) = @_;
+    my ( $WITH_PM, $batch_cb, $batch_size, $nproc, $stream_cb, ) =
+        @{$processed}{qw/ WITH_PM batch_cb batch_size nproc stream_cb  /};
+
+    while (
+        defined( my $batch = $stream_cb->( { size => $batch_size } )->{items} )
+        )
+    {
+        $batch_cb->($batch);
+    }
+    return;
+}
+
 1;
 
 __END__
@@ -90,7 +106,7 @@ Parallel::ForkManager::Segmented::Base - base class for Parallel::ForkManager::S
 
 =head1 VERSION
 
-version 0.2.1
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -117,6 +133,12 @@ Initializes a new object.
 
 Process the arguments passed to run().
 
+=head2 $obj->serial_run($process_args)
+
+Implement a (possibly naïve) serial run.
+
+Added in version 0.4.0.
+
 =head1 SEE ALSO
 
 =over 4
